# background
I would like to create a knowledge base for enterprise. the idea is now with AI, knowledge base is a critical asset for AI to learn my business, mean time my employee also can leverage this knowledge base to get the info they need. so there are several scenarios as below:
## scenarios
- AI agent to help maintain enterprise knowledge.
- AI agent to use these knowledge when it's work required
- employee also can have a portal to quickly view the knowledge in the knowledge base, just like a library.

## my questions
1. what's the way or lifecycle in modern way to use knowledge base (is there any other scenarios?)
2. is it a good name to call it knowledge base in modern context or in my scenarios
3. what's the challenge to fulfill the scenarios
4. any proposed tehcnical architecture
5. what's the implementation roadmap